import { Tooltip, Image, Tag } from 'antd';
import { doFetch } from '@/utils/doFetch';
const statusColors = {
    1: '#7ac143',
    2: 'orange',
    3: '#fa4659'
};
function getcolumns(setdrawer, activeKey) {
    const commona = [
        {
            title: '客户名称',
            dataIndex: 'customerName',
            key: 'customerId',
            valueType: 'select',
            options: { path: '/lease/umLeaseCustomer/getSelection', params: {} },
            fieldProps: {
                showSearch: true
            },
            fixed: 'left'
        },
        {
            title: '合同单号',
            dataIndex: 'contractNo',
            key: 'contractNo',
            fixed: 'left'
        },
        {
            title: '设备编号',
            dataIndex: 'equipmentNo',
            key: 'equipmentNo'
        },
        {
            title: '设备名称',
            dataIndex: 'equipmentName',
            key: 'equipmentName',
        },
        {
            title: '设备型号',
            dataIndex: 'equipmentModelName',
            key: 'equipmentModelName',
            hideInSearch: true
        },
        {
            title: '莫格云眼',
            dataIndex: 'intelligentUnitNo',
            key: 'intelligentUnitNo',
            width: 170
        },
        {
            title: '出库区域',
            dataIndex: 'shopName',
            key: 'shopName',
        }
    ],
        commonb = [
            {
                title: '每期单价',
                dataIndex: 'unitPrice',
                key: 'unitPrice',
                hideInSearch: true,
                width: 80
            },
            {
                title: '智享价',
                dataIndex: 'zxPrice',
                key: 'zxPrice',
                hideInSearch: true,
                width: 80
            },
            {
                title: '返利金额',
                dataIndex: 'rebatePrice',
                key: 'rebatePrice',
                hideInSearch: true,
                width: 80
            },
            {
                title: '交付运费',
                dataIndex: 'deliveryPrice',
                key: 'deliveryPrice',
                hideInSearch: true,
                width: 80
            },
            {
                title: '交付日期',
                dataIndex: 'deliveryDate',
                key: 'deliveryDate',
                hideInSearch: true
            },
            {
                title: '退还运费',
                dataIndex: 'returnFreight',
                key: 'returnFreight',
                hideInSearch: true,
                width: 80
            },
            {
                title: '退还日期',
                dataIndex: 'returnDate',
                key: 'returnDate',
                hideInSearch: true
            },
            {
                title: '返程运费承担方',
                dataIndex: 'returnBearName',
                key: 'returnBearName',
                hideInSearch: true,
                width: 120
            },
            {
                title: '押金',
                dataIndex: 'deposit',
                key: 'deposit',
                hideInSearch: true,
                width: 80
            },
            {
                title: '违约金',
                dataIndex: 'violatePrice',
                key: 'violatePrice',
                hideInSearch: true,
                width: 80
            }
        ],
        commonc = [
            {
                title: '开票期数',
                dataIndex: 'openNum',
                key: 'openNum',
                hideInSearch: true
            },
            {
                title: '已发生租金',
                dataIndex: 'occurredPrice',
                key: 'occurredPrice',
                hideInSearch: true
            },
            {
                title: '累计逾期欠费',
                dataIndex: 'overduePrice',
                key: 'overduePrice',
                hideInSearch: true
            },
            {
                title: '累计回款金额',
                dataIndex: 'collectionPrice',
                key: 'collectionPrice',
                hideInSearch: true
            },
            {
                title: '租金减免金额',
                dataIndex: 'reducePrice',
                key: 'reducePrice',
                hideInSearch: true
            },
            {
                title: '逾期次数',
                dataIndex: 'overdueNum',
                key: 'overdueNum',
                hideInSearch: true
            },
            {
                title: '开始租赁时间',
                dataIndex: 'startLeaseDate',
                key: 'startLeaseDateList',
                valueType: 'dateRange'
            },
            {
                title: '结束租赁时间',
                dataIndex: 'endLeaseDate',
                key: 'endLeaseDateList',
                valueType: 'dateRange'
            },
            {
                title: '实际结束时间',
                dataIndex: 'realEndDate',
                key: 'realEndDateList',
                valueType: 'dateRange'
            }
        ];
    return [
        {
            tab: '未完成',
            key: 'item-1',
            columns: [
                ...commona,
                {
                    title: '当前租期/租期',
                    dataIndex: 'thisTenancy',
                    key: 'thisTenancy',
                    render: (_, row) => {
                        return (
                            <a
                                className="table-cell"
                                onClick={() => {
                                    setdrawer && setdrawer((s) => ({
                                        ...s,
                                        open: true,
                                        item: row,
                                        val: 'only',
                                        title: '租期信息',
                                        type: 'detail'
                                    }));
                                }}
                            >
                                {row.thisTenancy + '/' + row.tenancyTotal}
                            </a>
                        );
                    },
                    hideInSearch: true,
                    width: 110
                },
                ...commonb,
                ...commonc,
                {
                    title: '回款状态',
                    dataIndex: 'collectionStatusName',
                    key: 'collectionStatus',
                    hideInForm: true,
                    valueType: 'select',
                    options: [
                        { label: '正常', value: 1 },
                        { label: '预警', value: 2 },
                        { label: '报警', value: 3 }
                    ],
                    fixed: 'right',
                    render: (_, row) => {
                        return <span style={{ color: statusColors[row.collectionStatus] }}>{row.collectionStatusName}</span>
                    },
                    width: 80
                },
            ]
        },
        {
            tab: '已完成',
            key: 'item-2',
            columns: [
                ...commona,
                {
                    title: '租期',
                    dataIndex: 'tenancyTotal',
                    key: 'tenancyTotal',
                    render: (_, row) => {
                        return (
                            <a
                                className="table-cell"
                                onClick={() => {
                                    setdrawer && setdrawer((s) => ({
                                        ...s,
                                        open: true,
                                        item: row,
                                        val: 'only',
                                        title: '租期信息',
                                        type: 'detail'
                                    }));
                                }}
                            >
                                {row.tenancyTotal}
                            </a>
                        );
                    },
                    hideInSearch: true
                },
                ...commonb,
                {
                    title: '入库区域',
                    dataIndex: 'returnShopName',
                    key: 'returnShopName',
                },
                ...commonc
            ]
        }
    ]



}
export default getcolumns;